import React, { Fragment } from 'react';
import {
  Card,
  Table,
  notification,
  DatePicker,
  Button,
  Row,
  Col,
  Input,
  Divider,
  Select,
  Badge,
  Form,
  Popconfirm
} from 'antd';
import * as Format from '@/utils/Format';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { getAnchorPageList, deleteTag } from '@/services/manage';
import router from 'umi/router';
import styles from './DemoList.less';
import Ellipsis from '@/components/Ellipsis';
import Zmage from 'react-zmage';
import { objFilter } from '../../utils/Help';
import moment from 'moment';

const { Column } = Table;
const Option = Select.Option;
const FormItem = Form.Item;
const { RangePicker } = DatePicker;

@Form.create()
class DemoList extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      pagination: {
        pageSize: 20,
        current: 1,
        total: 0,
      },
      userName: '',
    };
  }

  componentDidMount() {
    const storageParams = sessionStorage.getAnchorPageList;
    if (storageParams) {
      const params = JSON.parse(storageParams);
      const pagination = {
        pageSize: params.pageSize,
        current: params.pageNum,
        total: 0,
      };
      const formFields = {
        userName: params.userName,
        liveStatus: params.liveStatus,
        streamStatus: params.streamStatus,
      };
      if (params.startDate && params.endDate) {
        formFields.time = [moment(params.startDate), moment(params.endDate)];
      }
      this.props.form.setFieldsValue(formFields);
      this.setState({ pagination }, () => {
        //获取主播列表
        this.getAnchorPageList(this.state.pagination.current);
      });
    } else {
      this.getAnchorPageList(this.state.pagination.current);
    }
  }

  //获取主播列表
  getAnchorPageList(pageNum) {
    const { pagination, loading } = this.state;
    if (loading) return;
    this.setState({ loading: true }, async () => {
      const { userName, liveStatus, streamStatus, time } = this.props.form.getFieldsValue();
      const params = {
        liveStatus, //直播状态
        userName, //主播姓名
        streamStatus, //推流状态
        pageNum: pageNum ? pageNum : pagination.current,
        pageSize: pagination.pageSize,
        startDate: time && time.length > 0 ? time[0].valueOf() : null,
        endDate: time && time.length > 0 ? time[1].valueOf() : null,
      };
      objFilter(params); //去除空字段
      const res = await getAnchorPageList(params);
      if (res.code === 'OK') {
        const list = res.data.list || [];
        pagination.current = params.pageNum;
        pagination.total = res.data.total;
        this.setState({ list, loading: false, pagination });
        sessionStorage.getAnchorPageList = JSON.stringify(params);
      } else {
        this.setState({ loading: false });
      }
    });
  }

  // 翻页
  handlePage(page) {
    const pageNum = page.current;
    this.getAnchorPageList(pageNum);
  }

  //输入搜索名称
  handleSearchName(e) {
    this.setState({ userName: e.target.value });
  }

  //选择主播状态
  onSelectStatus(liveStatus) {
    this.setState({ liveStatus });
  }

  //跳转
  linkTo(url) {
    router.push(url);
  }

  //重置搜索
  resetSearch() {
    this.props.form.resetFields();
    sessionStorage.removeItem('getAnchorPageList');
  }

  testLog() {
    console.log(this.state);
  }

  //渲染搜索条件
  renderSearch() {
    const { loading } = this.state;
    const { getFieldDecorator } = this.props.form;
    return (
      <div className={styles.tableListForm}>
        <Form layout="inline">
          <Row gutter={{ md: 8, lg: 24, xl: 48 }} type="flex" justify="start">
            <Col md={8} sm={24}>
              <FormItem label="主播名称">
                {getFieldDecorator('userName')(<Input placeholder="请输入主播名称" allowClear />)}
              </FormItem>
            </Col>

            <Col md={8} sm={24}>
              <FormItem label="直播状态">
                {getFieldDecorator('liveStatus')(
                  <Select allowClear placeholder="请选择审核状态">
                    <Option key={101} value={101}>
                      <Badge status="processing" text="直播中" />
                    </Option>
                    <Option key={201} value={201}>
                      <Badge status="default" text="未开播" />
                    </Option>
                  </Select>,
                )}
              </FormItem>
            </Col>

            <Col md={8} sm={24}>
              <FormItem label="推流状态">
                {getFieldDecorator('streamStatus')(
                  <Select allowClear placeholder="请选择上架状态">
                    <Option key={101} value={101}>
                      <Badge status="processing" text="推流中" />
                    </Option>
                    <Option key={201} value={201}>
                      <Badge status="default" text="已关闭" />
                    </Option>
                  </Select>,
                )}
              </FormItem>
            </Col>

            <Col md={16} sm={24}>
              <FormItem label="审核时间">
                {getFieldDecorator('time')(
                  <RangePicker
                    showTime={{
                      defaultValue: [
                        moment('00:00:00', 'HH:mm:ss'),
                        moment('23:59:59', 'HH:mm:ss'),
                      ],
                    }}
                  />,
                )}
              </FormItem>
            </Col>
          </Row>
          <div style={{ marginBottom: 20 }}>
            <Button
              type="primary"
              loading={loading}
              icon="search"
              onClick={this.getAnchorPageList.bind(this, 1)}
            >
              查询
            </Button>
            <Button style={{ marginLeft: 20 }} icon="sync" onClick={this.resetSearch.bind(this)}>
              重置
            </Button>
          </div>
        </Form>
      </div>
    );
  }

  //删除标签
  deleteTag(tagId) {
    const { deteleLoading } = this.state;
    if (deteleLoading) return;
    this.setState({ deteleLoading: true }, async () => {
      const res = await deleteTag({ tagId });
      if (res.success) {
        notification.success({
          message: '标签删除成功',
        });
        this.setState({ deteleLoading: false }, () => {
          this.getTagPageList(this.state.pagination.current);
        });
      } else {
        this.setState({ deteleLoading: false });
      }
    });
  }

  render() {
    const { list } = this.state;
    return (
      <PageHeaderWrapper
        title={<span onClick={this.testLog.bind(this)}>{this.props.route.name}</span>}
      >
        <Card title="主播列表">
          {this.renderSearch()}
          <Table
            rowKey="userId"
            loading={this.state.loading}
            pagination={this.state.pagination}
            onChange={this.handlePage.bind(this)}
            dataSource={list}
          >
            <Column
              title="头像"
              dataIndex="productPic"
              key="productPic"
              render={productPic => (
                <Zmage
                  className={styles.productPic}
                  src={productPic + '!sq100'}
                  set={[{ src: productPic, alt: '主播主图' }]}
                />
              )}
            />
            <Column
              title="名称"
              key="userName"
              dataIndex="userName"
              render={userName => (
                <Ellipsis tooltip length={20}>
                  {userName}
                </Ellipsis>
              )}
            />
            <Column
              title="直播状态"
              key="liveStatus"
              dataIndex="liveStatus"
              render={liveStatus => (
                <Fragment>
                  {liveStatus === 101 && <Badge status="processing" text="直播中" />}
                  {liveStatus === 201 && <Badge status="default" text="未开播" />}
                </Fragment>
              )}
            />
            <Column
              title="推流状态"
              key="streamStatus"
              dataIndex="streamStatus"
              render={streamStatus => (
                <Fragment>
                  {streamStatus === 101 && <Badge status="processing" text="推流中" />}
                  {streamStatus === 201 && <Badge status="default" text="已关闭" />}
                </Fragment>
              )}
            />
            <Column
              title="审核时间"
              dataIndex="anchorAuthTime"
              key="anchorAuthTime"
              render={anchorAuthTime => {
                return <div>{Format.date(anchorAuthTime, 'yyyy-MM-dd HH:mm')}</div>;
              }}
            />
            <Column
              title="操作"
              key="option"
              dataIndex="option"
              render={(option, record, index) => {
                return (
                  <Fragment>
                    <a onClick={this.linkTo.bind(this, '/anchor/detail?userId=' + record.userId)}>
                      详情
                    </a>
                    <Divider type="vertical" />
                    <Popconfirm
                      title="确定删除吗？"
                      onConfirm={this.deleteTag.bind(this, record.tagId)}
                    >
                      <a>删除</a>
                    </Popconfirm>
                    <Divider type="vertical" />
                    <a>编辑</a>
                  </Fragment>
                );
              }}
            />
          </Table>
        </Card>
      </PageHeaderWrapper>
    );
  }
}

export default DemoList;
