/**
 * 
 * 修改密码
 */
import React, { Component } from 'react'
import { Modal, Form, Input, Row, Col } from 'antd'
import styles from './ResetPassword.less'
import { changePwd } from  '@/services/user'
import { showSuccess, encryptMd5 } from '@/utils/base'

// 表单响应配置
const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 4 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 18 },
  },
}

@Form.create()
class ResetPassword extends Component {
  constructor (props) {
    super(props)
    this.state = {
      uploading: false,
    }
  }

  onOk = () => {
    console.log('start')
    const { onOk, form } = this.props
    form.validateFieldsAndScroll(async (errors, values) => {
      if (errors) {
        return
      }
      const { oldPwd, newPwd } = values
      const _params = {
        oldPwd: encryptMd5(oldPwd), newPwd: encryptMd5(newPwd)
      }
      let _code = ''
      const _state = {
        uploading: false
      }
      try {
        this.setState({ uploading: true })
        const { code } = await changePwd(_params)
        _code = code
        
      } catch (e) {
        console.log(e)
      }
      this.setState(_state)
      if (_code === 'OK') {
        showSuccess('修改密码执行成功')
        onOk && onOk()
      }
    })
  }
  render () {
    const { currentUser, form } = this.props
    const { uploading } = this.state

    const { getFieldDecorator } = form

    return (
      <Modal
        title='修改密码'
        onCancel={this.props.onCancel}
        onOk={this.onOk}
        visible
        okButtonProps={{
          loading: uploading
        }}
      >
        <div className={styles['content-wrap']}>
          <Form {...formItemLayout}>
            <Row className={styles['item-line']}>
              <Col span={4} className={styles['item-line-left']}>姓名:</Col>
              <Col span={18}>{currentUser.adminName}</Col>
            </Row>
            <Row className={styles['item-line']}>
              <Col span={4} className={styles['item-line-left']}>手机号:</Col>
              <Col span={18}>{currentUser.adminPhone}</Col>
            </Row>
            <Form.Item
              label='老密码'
            >
              {getFieldDecorator('oldPwd', {
                rules: [{ required: true, message: '请输入老密码', whitespace: true }],
              })(
                <Input.Password 
                  placeholder='请输入老密码'
                />
              )}
            </Form.Item>
            <Form.Item
              label='新密码'
            >
              {getFieldDecorator('newPwd', {
                rules: [{ required: true, message: '请输入新密码', whitespace: true }],
              })(
                <Input.Password
                  placeholder='请输入新密码'
                />
              )}
            </Form.Item>
          </Form>
        </div>
      </Modal>
    )
  }
}
export default ResetPassword
