/**
 * Ant Design Pro v4 use `@ant-design/pro-layout` to handle Layout.
 * You can view component api by:
 * https://github.com/ant-design/ant-design-pro-layout
 */
import ProLayout, { DefaultFooter, PageLoading } from '@ant-design/pro-layout';
import React, { useEffect, useState } from 'react';
import Link from 'umi/link';
import { connect } from 'dva';
import { Result, Button, ConfigProvider } from 'antd';
import Authorized from '@/utils/Authorized';
import RightContent from '@/components/GlobalHeader/RightContent';
import { isAntDesignPro, getAuthorityFromRouter } from '@/utils/utils';
import logo from '../assets/logo.png';
import Cookie from '@/utils/Cookie'
import router from 'umi/router'

const noMatch = (
  <Result
    status="403"
    title="403"
    subTitle="Sorry, you are not authorized to access this page."
    extra={
      <Button type="primary">
        <Link to="/user/login">Go Login</Link>
      </Button>
    }
  />
);
/**
 * use Authorized check all menu item
 */

const menuDataRender = menuList =>
  menuList.map(item => {
    const localItem = { ...item, children: item.children ? menuDataRender(item.children) : [] };
    return Authorized.check(item.authority, localItem, null);
  });

const defaultFooterDom = (
  <DefaultFooter
    copyright="2019 浙江帕趣网络科技有限公司"
    links={[]}
  />
);

const footerRender = () => {
  if (!isAntDesignPro()) {
    return defaultFooterDom;
  }

  return (
    <>
      {defaultFooterDom}
      <div
        style={{
          padding: '0px 24px 24px',
          textAlign: 'center',
        }}
      >
        <a href="https://www.netlify.com" target="_blank" rel="noopener noreferrer">
          <img
            src="https://www.netlify.com/img/global/badges/netlify-color-bg.svg"
            width="82px"
            alt="netlify logo"
          />
        </a>
      </div>
    </>
  );
};

const BasicLayout = props => {
  //console.log('BasicLayout ', props);
  const {
    dispatch,
    children,
    settings,
    location = {
      pathname: '/',
    },
  } = props;
  /**
   * constructor
   */

  useEffect(() => {
    if (!Cookie.get('_xy_tk_chanel', { path: '/' })) {
      router.replace('/user/login')
      return
    }
    if (dispatch) {
      dispatch({
        type: 'user/fetchCurrent',
      });
      // dispatch({
      //   type: 'menu/getMenus',
      // });
    }
  }, []);
  /**
   * init variables
   */

  const handleMenuCollapse = payload => {
    if (dispatch) {
      dispatch({
        type: 'global/changeLayoutCollapsed',
        payload,
      });
    }
  }; // get children authority

  const authorized = getAuthorityFromRouter(props.route.routes, location.pathname || '/') || {
    authority: undefined,
  };
  const { userLoading } = props.user
  return (
    <ProLayout
      logo={logo}
      menuHeaderRender={(logoDom, titleDom) => {
        return (
          <Link to="/">
            {logoDom}
            {titleDom}
          </Link>
        )
      }}
      onCollapse={handleMenuCollapse}
      menuItemRender={(menuItemProps, defaultDom) => {
        if (menuItemProps.isUrl || menuItemProps.children) {
          return defaultDom;
        }

        return <Link to={menuItemProps.path}>{defaultDom}</Link>;
      }}
      // menuRender={(_, dom) => {
      //     return(
      //       props.fetchMenuLoading ? (
      //         <div
      //           style={{
      //             width: 256,
      //             background: '#001529',
      //           }}
      //         >
      //           <PageLoading />
      //         </div>
      //       ) : (
      //           dom
      //         )
      //     )
      //   }
      // }
      breadcrumbRender={(routers = []) => [
        {
          path: '/',
          breadcrumbName: '首页',
        },
        ...routers,
      ]}
      itemRender={(route, params, routes, paths) => {
        const first = routes.indexOf(route) === 0;
        return first ? (
          <Link to={paths.join('/')}>{route.breadcrumbName}</Link>
        ) : (
            <span>{route.breadcrumbName}</span>
          );
      }}
      footerRender={footerRender}
      menuDataRender={menuDataRender}
      //menuDataRender={() => props.menuData}
      rightContentRender={() => <RightContent />}
      {...props}
      {...settings}
    >
      <Authorized authority={authorized.authority} noMatch={noMatch}>
        {userLoading ? <div /> : children}
      </Authorized>
    </ProLayout>
  );
};

export default connect(({ global, settings, menu, user }) => ({
  // 用户信息
  user,
  collapsed: global.collapsed,
  settings,
  menuData: menu.menuData,
  fetchMenuLoading: menu.fetchMenuLoading,      //加载菜单
}))(BasicLayout);
