/**
 * 
 * 主播审核列表
 */
import React, { Component } from 'react'
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import router from 'umi/router'
import { Card, Table, Divider, Icon, Modal, Menu, Dropdown }  from 'antd' 
import styles from './AnchorAuditList.less'
// 引入接口
import { getAuditPageList, denyAudit, passAudit } from './api'
// 引入模块公用组件
import { AuditFilters, AuditApprove } from './components'
// 引入公用函数
import { getDate, showSuccess, showError } from '@/utils/base'
// 引入模块公用函数
import { getAuditStatus } from './common'
// 引入img
import ZImage from 'react-zmage'
// 引入弹窗组件
import { ModalInput } from '@/components/Modals'
// 引入connect
import { connect } from 'dva'

// table 列组件
const Column = Table.Column
// 本地存储key
const storeName = 'anchorAuditListStore'
// 列表组件
@connect(({ user }) => ({
  currentUser: user.currentUser
}))
class AnchorAuditList extends Component {
  constructor (props) {
    super(props)
    this.state = {
      // 加载列表 loading
      loading: false,
      // 列表数据
      list: [],
      // 状态
      auditStatus: '0',
      applyType: 'all',
      // 分页
      pagination: {
        current: 1
      }
    }
  }
  componentDidMount () {
    const _state = {}
    // 地址中存在 useStore 的值将从本地获取state数据
    if (this.props.location.query.useStore) {
      // 使用本地数据
      const jsonString = sessionStorage[storeName]
      // 解析本地json数据
      if (jsonString) {
        const json = JSON.parse(jsonString)
        // 合并到state
        Object.assign(_state, json)
      }
      // 去除地址拦中query的变量
      router.replace({
        pathname: this.props.location.pathname
      })
      // 移除本地数据
      sessionStorage.removeItem(storeName)
    }
    
    this.setState(_state, this.getList)
  }

  // 新增
  onCreate = () => {
    router.push({
      pathname: '/family/list/create'
    })
  }
  
  // 获取列表
  getList = async () => {
    const { agentId } = this.props.currentUser
    if (!agentId) {
      return
    }
    const _state  = {
      loading: false
    }
    try {
      const { auditStatus, userName, applyType, startTime, endTime, pagination } = this.state
      // 页码，每页条数
      const _params = {
        pageNum: pagination.current || 1,
        pageSize: 10,
        agentId
      }
      // 用户名
      if (userName) {
        _params.userName = userName
      }

      // 审核状态
      if (auditStatus && auditStatus !== 'all') {
        _params.auditStatus = auditStatus
      }

      // 申请类型
      if (applyType && applyType !== 'all') {
        _params.applyType = applyType
      }
      // 开始结束时间
      if (startTime) {
        _params.startTime = startTime
        _params.endTime = endTime
      }

      this.setState({ loading: true })
      const { data, code } = await getAuditPageList(_params)
      if (code === 'OK' && data) {
        const { list, total, pageIndex, pageSize } = data
        // 列表数据
        _state.list = list
        // 页码信息
        _state.pagination = {
          current: pageIndex,
          total: total,
          pageSize: pageSize
        }
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }

  // 子组建内容变化
  onChange = (name, value) => {
    if (Array.isArray(name)) {
      let _state = {}
      name.map((item) => {
        _state[item.name] = item.value
      })
      this.setState(_state)
      return
    }
    this.setState({ [name]: value })
  }
  // 搜索
  onSearch = () => {
    const { pagination } = this.state 
    pagination.current = 1
    this.setState({ pagination }, this.getList)
  }

  onPageChange = (pagination) => {
    this.setState({ pagination }, this.getList)
  }

  // 通过
  onAgree = ({ auditId, agentId }) => {
    AuditApprove({
      auditId,
      agentId,
      onOk: () => {
        showSuccess('通过操作执行成功')
        this.getList()
      }
    })
    return
    let msg = ''
    Modal.confirm({
      title: `${msg}提示`,
      content: `确定要执行${msg}操作么?`,
      okText: '确定',
      okType: 'primary',
      cancelText: '取消',
      onOk: () => { 
        return passAudit({ auditId })
        .then(({ code }) => {
          if (code === 'OK') {
            showSuccess(msg + '操作执行成功')
            this.getList()
          }
        })
      }
    })
  }

  // 驳回
  onReject = ({ auditId }) => {
    ModalInput({
      title: '驳回理由',
      required: true,
      onOk: (auditMsg) => {
        return denyAudit({ auditId, auditMsg })
        .then(({ code }) => {
          if (code === 'OK') {
            showSuccess('驳回操作执行成功')
            this.getList()
          }
        })
      }
    })
  }
  render () {
    const { 
      loading, list, userName, pagination, startTime, endTime, applyType,
      auditStatus,
    } = this.state
    // 页码信息
    const { total, current, pageSize } = pagination
    // 石否隐藏 分页信息
    const hidePagination = current === 1 && pageSize >= total
    return (
      <PageHeaderWrapper title='主播审核列表'>
        <Card>
          <AuditFilters 
            applyType={applyType}
            auditStatus={auditStatus}
            onChange={this.onChange}
            userName={userName}
            onSearch={this.onSearch}
            startTime={startTime}
            endTime={endTime}
          />
          <Table
            loading={loading}
            dataSource={list}
            rowKey={(auditId, applyTime) => `${auditId}-${applyTime}`}
            onChange={this.onPageChange}
            bordered
            pagination={hidePagination ? false : pagination}
          >
            <Column 
              title='主播头像'
              key='userAvatar'
              dataIndex='userAvatar'
              render={(text, { userAvatar }) => (
                userAvatar ? <ZImage src={userAvatar} style={{width: 50}} /> : '-'
              )}
            />
            <Column 
              title='昵称'
              key='userName'
              dataIndex='userName'
            />
            <Column 
              title='性别'
              key='userSex'
              dataIndex='userSex'
              render={userSex => (
                userSex === 1 
                ? <Icon type="man" style={{ color: '#1890ff' }}/> 
                : userSex === 2
                  ? <Icon type="woman" style={{ color: '#eb2f96' }}/>
                  : '-'
              )}
            />
            <Column 
              title='星芽号'
              key='userNo'
              dataIndex='userNo'
            />
            <Column 
              title='等级'
              key='charmLevel'
              dataIndex='charmLevel'
            />
            <Column 
              title='财富等级'
              key='wealthLevel'
              dataIndex='wealthLevel'
            />
            <Column 
              title='粉丝数量'
              key='fansCount'
              dataIndex='fansCount'
            />
            <Column 
              title='申请时间'
              key='applyTime'
              dataIndex='applyTime'
              render={(text, { applyTime }) => (
                <div>{applyTime ? getDate(applyTime, 'yyyy-MM-dd hh:mm') : '-'}</div>
              )}
            />
            <Column 
              title='申请理由'
              key='applyMsg'
              dataIndex='applyMsg'
              width='20%'
              render={(text, { applyMsg }) => (
                <div>{applyMsg || '-'}</div>
              )}
            />
            <Column 
              title='审核状态'
              key='auditStatus'
              dataIndex='auditStatus'
              render={(text, { auditStatus }) => getAuditStatus(auditStatus)}
            />
            <Column 
              title='操作'
              key='actions'
              dataIndex='actions'
              align='center'
              render={(text, record) => (
                record.auditStatus === 0 
                ? <div className={styles['list-actions']}>
                  <a href="#" onClick={e => {
                    e.preventDefault()
                    this.onAgree(record)
                  }}>通过</a>
                  <Divider type='vertical' />
                  <a href="#" onClick={e => {
                    e.preventDefault()
                    this.onReject(record)
                  }}>驳回</a>
                </div>
                : '-'
              )}
            />
          </Table>
        </Card>
      </PageHeaderWrapper>
    )
  }
}
export default AnchorAuditList
