/**
 * 
 * 通过
 */
import React, { Component } from 'react'
import { Modal, Select, Form, Switch, Input, InputNumber } from 'antd'
import { positionArray } from '../../common'
import styles from './AuditApprove.less'
import { passAudit, getAnchorRatio } from '../../api'
import Decimal from 'decimal.js'

const _style = {
  width: '100%'
}
// 下拉框
const Option = Select.Option
const TextArea = Input.TextArea

// 表单响应配置
const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 6 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 16 },
  },
}
const spItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 6 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 18 },
  },
}
@Form.create()
class AuditApprove extends Component {
  constructor (props) {
    super(props)
    this.state = {
      leval: '2'
    }
  }
  componentDidMount () {
    const { agentId } = this.props 
    if (agentId) {
      this.getRadio(agentId)
    }
  }

  // 获取默认比例
  getRadio = async (agentId) => {
    try {
      const { code, data } = await getAnchorRatio({ agentId })
      if (code === 'OK') {
        const _anchorRatio = data || data === 0 ? new Decimal(data).mul(new Decimal(100)).toNumber() : undefined
        this.props.form.setFieldsValue({
          anchorRatio: _anchorRatio
        })
      }
    } catch (e) {
      console.log(e)
    }
  }
  // 点击确定 上传数据
  onOk = () => {
    const { form, auditId } = this.props 
    form.validateFieldsAndScroll((errors, values) => {
      if (errors) {
        return
      }
      const { 
        anchorRatio,
        ...others 
      } = values
      const params = others
      params.anchorRatio = new Decimal(anchorRatio).div(new Decimal(100)).toNumber()
      params.auditId = auditId
      this.onPost(params)
    })
  }
  // 上传数据
  onPost = async (params) => {
    let _code = ''
    try {
      this.setState({ uploading: true })
      const { code } = await passAudit(params)
      _code = code
    } catch (e) {
      console.log(e)
    }
    this.setState({ uploading: false })
    if (_code === 'OK') {
      const { onOk } = this.props 
      onOk && onOk()
    }
  }
  render () {
    const { uploading } = this.state
    const { form } = this.props 
    const { getFieldDecorator } = form
    return (
      <Modal
        title='审批通过'
        onCancel={this.props.onCancel}
        onOk={uploading ? null : this.onOk}
        okButtonProps={{ loading: uploading }}
        visible
      >
        <Form {...formItemLayout}>
          <Form.Item
            label='主播提成比例'
            hidden
          >
            {getFieldDecorator('anchorRatio', {
              rules: [{ required: true, message: '请输入主播提成比例' }]
            })(
              <InputNumber 
                placeholder='请输入主播提成比例'
                step={1}
                min={0}
                max={100}
                precision={2}
                formatter={value => `${value}%`}
                parser={value => value.replace('%', '')}
                style={{ width: '100%' }}
              />
            )}
          </Form.Item>
          <Form.Item
            label='审批意见'
          >
            {getFieldDecorator('auditMsg', {
              rules: [{ required: false, message: '请输入审批意见' }],
            })(
              <TextArea 
                placeholder='请输入审批意见'
              />
            )}
          </Form.Item>
        </Form>
      </Modal>
    )
  }
}
export default AuditApprove
