/**
 * 
 * 统计列表
 */
import React, { Component } from 'react'
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import router from 'umi/router'
import { Card, Table, Divider, Button, Modal, Dropdown, Menu }  from 'antd' 
import styles from './CountList.less'
// 引入接口
import { getStatPlatformPageList, getChannelPageList } from './api'
// 引入公用函数
import { getDate, showSuccess, showError, formatTimeLabel, getStatPlatformType } from '@/utils/base'
import { Filters } from './components'

// table 
const Column = Table.Column
const storeName = 'CountListStore'

class CountList extends Component {
  constructor (props) {
    super(props)
    this.state = {
      // 加载列表 loading
      loading: false,
      // 列表数据
      list: [],
      channelId: '',
      statType: 10200,
      statTimeType: 4,
      channels: [],
      // 分页
      pagination: {
        current: 1
      }
    }
  }
  componentDidMount () {
    this.getChannelPageList()
    const _state = {}
    if (this.props.location.query.useStore) {
      // 使用本地数据
      const jsonString = sessionStorage[storeName]
      if (jsonString) {
        const json = JSON.parse(jsonString)
        Object.assign(_state, json)
      }
      router.replace({
        pathname: this.props.location.pathname
      })
      sessionStorage.removeItem(storeName)
    }
    
    this.setState(_state, this.getList)
  }

  // 获取
  getChannelPageList = async () => {
    try {
      const { data, code } = await getChannelPageList({ pageIndex: 1, pageSize: 200, status: 1 })
      if (code === 'OK' && data) {
        this.setState({ channels: data.list })
      }
    } catch (e) {
      console.log(e)
    }
  }
  
  // 获取列表
  getList = async () => {
    const _state = {
      loading: false
    }
    try {
      const { 
        statType, statTimeType, startTime, endTime, pagination,
        channelId
      } = this.state
      // 页码，每页条数
      const _params = {
        pageIndex: pagination.current || 1,
        pageSize: 10
      }
      // 渠道id
      if (channelId) {
        _params.channelId = channelId
      }
      // 统计类型
      if (statType) {
        _params.statType = statType
      }
      // 统计时间类型
      if (statTimeType) {
        _params.statTimeType = statTimeType
      }
      // 开始结束时间
      if (startTime) {
        _params.startTime = startTime
        _params.endTime = endTime
      }

      this.setState({ loading: true })
      const { data, code } = await getStatPlatformPageList(_params)
      if (code === 'OK' && data) {
        const { list, total, pageIndex, pageSize } = data
        _state.list = list
        _state.statType2 = +statType
        _state.pagination = {
          current: pageIndex,
          total: total,
          pageSize: pageSize
        }
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }

  // 获取支付方式
  getPayWayStr = (payWay) => {
    const { payWays } = this.state
    const obj = payWays && payWays.find(item => item.code === payWay)
    return obj ? obj.desc : '-'
  }
  // 子组建内容变化
  onChange = (name, value) => {
    if (Array.isArray(name)) {
      let _state = {}
      name.map((item) => {
        _state[item.name] = item.value
      })
      this.setState(_state)
      return
    }
    this.setState({ [name]: value })
  }
  // 搜索
  onSearch = () => {
    const { pagination } = this.state 
    pagination.current = 1
    this.setState({ pagination }, this.getList)
  }

  onPageChange = (pagination) => {
    this.setState({ pagination }, this.getList)
  }
 

  render () {
    const { 
      loading, list, pagination, channels, statType2,
      startTime, endTime, 
      statType, channelId, statTimeType
    } = this.state
    const { total, current, pageSize } = pagination
    const hidePagination = current === 1 && pageSize >= total
    return (
      <PageHeaderWrapper 
        title='统计列表'
      >
        <Card>
          <Filters 
            statTimeType={statTimeType}
            channelId={channelId}
            statType={statType}
            onChange={this.onChange}
            onSearch={this.onSearch}
            startTime={startTime}
            endTime={endTime}
            channels={channels}
          /> 
          <Table
            loading={loading}
            dataSource={list}
            rowKey={(record, i) => i}
            onChange={this.onPageChange}
            bordered
            pagination={hidePagination ? false : pagination}
          >
            <Column 
              title='渠道'
              key='channelName'
              dataIndex='channelName'
            />
            <Column 
              title={getStatPlatformType(statType2)}
              key='statValue'
              dataIndex='statValue'
            />
            <Column 
              title='时间'
              key='statTime'
              dataIndex='statTime'
              render={(text, { statTime }) => (formatTimeLabel(statTime))}
            />
          </Table>
        </Card>
      </PageHeaderWrapper>
    )
  }
}
export default CountList
