/**
 * 
 * 时段统计筛选条件
 */
import React, { Component } from 'react'
import styles from './FilterParts.less'
import { Select, Input, Button, DatePicker, InputNumber, Card } from 'antd'
import moment from 'moment'
import { regIntNumber, statPlatformTypeArray, stateTimeTypeArray, showError } from '@/utils/base'
import { getAllChannel } from '../api' 
import { TimeRange } from '@/components/Filters'

const Option = Select.Option
const RangePicker = DatePicker.RangePicker
const _style = {
  width: '100%'
}
const _cardBodyStyle = {
  padding: '10px 24px'
}
class FilterParts extends Component {
  constructor (props) {
    super(props)
    this.state = {
      channels: []
    }
  }
  componentDidMount () {
    this.onInit()
  }
  onInit = async () => {
    const _state = {}
    try {
      const { code, data } = await getAllChannel()
      if (code === 'OK') {
        _state.channels = data
      }
    } catch (e) {
      console.log(e)
    } finally {
      this.setState(_state)
    }
  }
  
  onPlatTypeChange = key => {
    const { onChange } = this.props
    onChange && onChange('statType', key)
  }
  onTimeTypeChange = key => {
    const { onChange } = this.props
    onChange && onChange('statTimeType', key)
  }
  onChannelChange = key => {
    if (key && key.length === 1 && key[0] === 'all') {
      // 选择了全部
    } else if (key && key.some(item => item === 'all')) {
      // 存在全部按钮
      key = key.filter(item => item !== 'all')
    }
    const { onChange } = this.props
    onChange && onChange('channelId', key)
  }
  // 时间筛选
  onDateChange = (moments) => {
    let _startTime
    let _endTime
    if (moments && moments.length) {
      _startTime = moments[0].startOf('date')
      _endTime = moments[1].endOf('date')

      // 时间限制
      const _days = 90
      const thirtyDaysStamp = _days * 24 * 3600 * 1000
      if (_endTime.valueOf() - _startTime.valueOf() >= thirtyDaysStamp) {
        showError(`时间区间不能大于${_days}天`)
        return
      }
    }
    const { onChange } = this.props
    onChange && onChange([{ name: 'startTime', value: _startTime }, { name: 'endTime', value: _endTime }])
  }
  render () {
    const { channels } = this.state
    const { 
      statType, onSearch, statTimeType, startTime, endTime, channelId
    } = this.props
    return (
      <Card className={styles['card-cls']} bodyStyle={_cardBodyStyle}>
        <div className={styles['wrap']}>
          <div className={`${styles['filter-item']} ${styles['filter-item-channel']}`}>
            <h4 className={styles['filter-label']}>渠道:</h4>
            <Select
              style={_style}
              placeholder='请选择渠道'
              value={channelId ? channelId : undefined}
              onChange={this.onChannelChange}
              allowClear
              mode='multiple'
            >
              <Option key='all'>全部</Option>
              {
                channels && channels.map((item) => (
                  <Option key={item.channelId}>{item.channelName}</Option>
                ))
              }
            </Select>
          </div>
          <div className={styles['filter-item']} hidden>
            <h4 className={styles['filter-label']}>统计类型:</h4>
            <Select
              style={_style}
              placeholder='请选择统计类型'
              value={statType ? statType.toString() : undefined}
              onChange={this.onPlatTypeChange}
              allowClear={false}
            >
              {
                statPlatformTypeArray && statPlatformTypeArray.map((item) => (
                  <Option key={item.key}>{item.value}</Option>
                ))
              }
            </Select>
          </div>
          <div className={styles['filter-item']} hidden>
            <h4 className={styles['filter-label']}>时间类型:</h4>
            <Select
              style={_style}
              placeholder='请选择统计类型'
              value={statTimeType ? statTimeType.toString() : undefined}
              onChange={this.onTimeTypeChange}
              allowClear={false}
            >
              {
                stateTimeTypeArray && stateTimeTypeArray.map((item) => (
                  <Option key={item.key}>{item.value}</Option>
                ))
              }
            </Select>
          </div>
          <div className={`${styles['filter-item']} ${styles['filter-item-time']}`}>
            <h4 className={styles['filter-label']}>创建时间:</h4>
            <TimeRange 
              style={_style}
              onChange={this.onDateChange}
              value={startTime ? [moment(startTime), moment(endTime)] : undefined}
              showFooter
              allowClear={false}
            />
          </div>
          <div className={styles['btn-wrap']}>
            <Button
              icon='search'
              onClick={onSearch}
              type='primary'
            >搜索</Button>
          </div>
        </div>
      </Card>
    )
  }
}
export default FilterParts
