/**
 * 
 * 礼物配置列表列表 筛选条件
 */
import React, { Component } from 'react'
import styles from './Filters.less'
import { Select, Input, Button, DatePicker, InputNumber } from 'antd'
import moment from 'moment'
import { regIntNumber, statPlatformTypeArray, stateTimeTypeArray } from '@/utils/base'

const Option = Select.Option
const RangePicker = DatePicker.RangePicker
const _style = {
  width: '100%'
}
class Filters extends Component {
  
  onPlatTypeChange = key => {
    const { onChange } = this.props
    onChange && onChange('statType', key)
  }
  onTimeTypeChange = key => {
    const { onChange } = this.props
    onChange && onChange('statTimeType', key)
  }
  onChannelChange = key => {
    const { onChange } = this.props
    onChange && onChange('channelId', key)
  }
  // 时间筛选
  onDateChange = (moments) => {
    let _startTime
    let _endTime
    if (moments && moments.length) {
      _startTime = moments[0].startOf('date')
      _endTime = moments[1].endOf('date')
    }
    const { onChange } = this.props
    onChange && onChange([{ name: 'startTime', value: _startTime }, { name: 'endTime', value: _endTime }])
  }
  render () {
    const { 
      statType, onSearch, statTimeType, startTime, endTime, channels, channelId
    } = this.props
    return (
      <div className={styles['wrap']}>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>渠道:</h4>
          <Select
            style={_style}
            placeholder='请选择渠道'
            value={channelId ? channelId.toString() : undefined}
            onChange={this.onChannelChange}
            allowClear
          >
            {
              channels && channels.map((item) => (
                <Option key={item.channelId}>{item.channelName}</Option>
              ))
            }
          </Select>
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>统计类型:</h4>
          <Select
            style={_style}
            placeholder='请选择统计类型'
            value={statType ? statType.toString() : undefined}
            onChange={this.onPlatTypeChange}
            allowClear={false}
          >
            {
              statPlatformTypeArray && statPlatformTypeArray.map((item) => (
                <Option key={item.key}>{item.value}</Option>
              ))
            }
          </Select>
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>时间类型:</h4>
          <Select
            style={_style}
            placeholder='请选择统计类型'
            value={statTimeType ? statTimeType.toString() : undefined}
            onChange={this.onTimeTypeChange}
            allowClear={false}
          >
            {
              stateTimeTypeArray && stateTimeTypeArray.map((item) => (
                <Option key={item.key}>{item.value}</Option>
              ))
            }
          </Select>
        </div>
        <div className={`${styles['filter-item']} ${styles['filter-item-time']}`} hidden>
          <h4 className={styles['filter-label']}>创建时间:</h4>
          <RangePicker 
            style={_style}
            onChange={this.onDateChange}
            value={startTime ? [moment(startTime), moment(endTime)] : undefined}
          />
        </div>
        <div className={styles['btn-wrap']}>
          <Button
            icon='search'
            onClick={onSearch}
            type='primary'
          >搜索</Button>
        </div>
      </div>
    )
  }
}
export default Filters
