import echarts from 'echarts'
import { getXAxisArray } from './common'
import numeral from 'numeral'
const z = num => num >= 10 ? num + '' : '0' + num

// 获取名称
export const getChannelNames = (channels) => {
  let _result = []
  channels && channels.forEach((item) => {
    _result.push(item.channelName)
  })
  return _result
}

//设置data
export const formateData = (channels) => {
  let _result = []
  channels && channels.forEach((item, i) => {
    _result.push({
      name: item.channelName,
      type: 'line',
      stack: '总量',
      symbolSize: 8,
      data: item.datas.map(item => item.statValue)// [120 + i, 132 + i, 101 + i, 134 + i, 90 + i, 230 + i, 210 + i]
    })
  })
  return _result
}


export const lineInit = (node, {
  // 时间类型
  timeType,
  // 渠道列表
  channels,
  // 开始时间 如果是单选下拉 数据放在startTime
  startTime,
  // 结束时间 
  endTime,
} = {}) => {
  if (!node) {
    return
  }
  const myChart = echarts.init(node)
  // 指定图表的配置项和数据
  const option = {
    tooltip: {
      trigger: 'axis'
    },
    legend: {
      data: getChannelNames(channels)
        // data: ['安装数', '下载次数', '注册用户数', '充值金额', '首充金额']
    },
    grid: {
      left: '3%',
      right: '4%',
      bottom: '3%',
      top: '8%',
      containLabel: true
    },
    toolbox: {
      feature: {
        saveAsImage: {}
      },
      show: false,
    },
    xAxis: {
      type: 'category',
      boundaryGap: false,
      data: getXAxisArray({ timeType, startTime, endTime })// ['周一', '周二', '周三', '周四', '周五', '周六', '周日']
    },
    yAxis: {
      type: 'value'
    },
    series: formateData(channels)
  };

  // 使用刚指定的配置项和数据显示图表。
  myChart.setOption(option);
}

// 总计折线图
export const totalLine = (node, {
  // 时间类型
  timeType,
  // 渠道列表
  totalStat,
  // 开始时间 如果是单选下拉 数据放在startTime
  startTime,
  // 结束时间 
  endTime,
} = {}) => {
  if (!node) {
    return
  }
  const myChart = echarts.init(node)
  const fillArray = getXAxisArray({ timeType, startTime, endTime, isDataIndex: true })

  totalStat && totalStat.forEach((item) => {
    fillArray.some((subItem) => {
      if (subItem.key === item.statTime) {
        subItem.statValue = item.statValue
        return true
      }
    })
  })

  // 指定图表的配置项和数据
  const option = {
    tooltip: {
      trigger: 'axis',
      formatter: (params) => {
        const { value, name } = params[0]
        let _value = value
        if (!value) {
          _value = value
        } else if (value.indexOf('.') !== -1) {
          _value = numeral(value).format('0,0.00')
        } else {
          _value = numeral(value).format('0,0')
        }
        return `${name}总计: ${_value}`
      }
    },
    legend: {
      data: ['汇总']
    },
    grid: {
      left: '3%',
      right: '4%',
      bottom: '3%',
      top: '4%',
      containLabel: true
    },
    toolbox: {
      feature: {
        saveAsImage: {}
      },
      show: false,
    },
    xAxis: {
      type: 'category',
      boundaryGap: false,
      data: getXAxisArray({ timeType, startTime, endTime }) // ['周一', '周二', '周三', '周四', '周五', '周六', '周日']
    },
    yAxis: {
        type: 'value'
    },
    series: [
      {
        type: 'line',
        stack: '总量',
        symbolSize: 8,
        data: fillArray.map(item => item.statValue)
      }
    ]
  };

  // 使用刚指定的配置项和数据显示图表。
  myChart.setOption(option);
}

// 时段统计中间的折线图
export const durationMiddleLine = (node, {
  middleData, targetDataName, oneWeekAgoDataName
} = {}) => {
  if (!node || !middleData) {
    return
  }
  const myChart = echarts.init(node)

  const { rangData, yesterdayData, oneWeekAgoData } = middleData

  const _legend = [targetDataName, '昨日', oneWeekAgoDataName]
  // 横坐标
  const xAxis = []
  const _targetData = []
  const _yesterdayData = []
  const _oneWeekAgoData = []
  for (let i = 0; i <= 23; i++) {
    xAxis.push(`${i}`)
    _targetData.push({ result: 0, key: z(i) })
    _yesterdayData.push({ result: 0, key: z(i) })
    _oneWeekAgoData.push({ result: 0, key: z(i) })
  }
  
  rangData && rangData.forEach((item, i) => {
    // const key = item.statTime.substring(0, 8)
    const obj = _targetData.find(subItem => subItem.key === item.hourStr)
    if (obj) {
      obj.result = item.result || 0
    }
  })
  yesterdayData && yesterdayData.forEach((item, i) => {
    // const key = item.statTime.substring(0, 8)
    const obj = _yesterdayData.find(subItem => subItem.key === item.hourStr)
    if (obj) {
      obj.result = item.result || 0
    }
  })
  oneWeekAgoData && oneWeekAgoData.forEach((item, i) => {
    // const key = item.statTime.substring(0, 8)
    const obj = _oneWeekAgoData.find(subItem => subItem.key === item.hourStr)
    if (obj) {
      obj.result = item.result || 0
    }
  })

  // 数据集
  const _seriesData = [
    { 
      name: targetDataName,
      type: 'line',
      symbolSize: 8,
      data: _targetData.map((item) => item.result)
    },
    { 
      name: '昨日',
      type: 'line',
      symbolSize: 8,
      data: _yesterdayData.map((item) => item.result)
    },
    { 
      name: oneWeekAgoDataName,
      type: 'line',
      symbolSize: 8,
      data: _oneWeekAgoData.map((item) => item.result)
    },
  ]
  

  // 指定图表的配置项和数据
  const option = {
    tooltip: {
      trigger: 'axis',
      // formatter: (params) => {
      //   const { value, name } = params[0]
      //   let _value = value
      //   if (!value) {
      //     _value = value
      //   } else if (value.indexOf('.') !== -1) {
      //     _value = numeral(value).format('0,0.00')
      //   } else {
      //     _value = numeral(value).format('0,0')
      //   }
      //   return `${name}总计: ${_value}`
      // }
    },
    legend: {
      data: _legend // ['汇总']
    },
    grid: {
      left: '3%',
      right: '4%',
      bottom: '3%',
      top: '10%',
      containLabel: true
    },
    toolbox: {
      feature: {
        saveAsImage: {}
      },
      show: false,
    },
    xAxis: {
      type: 'category',
      boundaryGap: false,
      data: xAxis // ['周一', '周二', '周三', '周四', '周五', '周六', '周日']
    },
    yAxis: {
      type: 'value'
    },
    series: _seriesData
  };

  // 使用刚指定的配置项和数据显示图表。
  myChart.setOption(option);
}

// ====================================================================
// 整体趋势折线图
export const totalMiddleLine = (node, {
  middleData, targetDataName
} = {}) => {
  if (!node || !middleData) {
    return
  }
  const myChart = echarts.init(node)

  const { datas } = middleData

  // const _legend = [targetDataName]
  // 横坐标
  const xAxis = []
  const _targetData = []

  datas && datas.forEach((item, i) => {
    let key = item.date.substring(4)
    key = key.replace(/^.{2}/, (match) => {
      return `${match}-`
    })
    xAxis.push(key)
    _targetData.push({
      result: item.result
    })
  })

  // 数据集
  const _seriesData = [
    { 
      name: targetDataName,
      type: 'line',
      symbolSize: 8,
      data: _targetData.map((item) => item.result)
    }
  ]

  // 指定图表的配置项和数据
  const option = {
    tooltip: {
      trigger: 'axis',
      formatter: (params) => {
        const { value, name } = params[0]
        let _value = value
        if (!value) {
          _value = value
        } else if (value.indexOf('.') !== -1) {
          _value = numeral(value).format('0,0.00')
        } else {
          _value = numeral(value).format('0,0')
        }
        return `${name}: ${_value}`
      }
    },
    legend: {
      data: [] // _legend // ['汇总']
    },
    grid: {
      left: '3%',
      right: '4%',
      bottom: '6%',
      top: '10%',
      containLabel: true
    },
    toolbox: {
      feature: {
        saveAsImage: {}
      },
      show: false,
    },
    xAxis: {
      type: 'category',
      boundaryGap: false,
      data: xAxis, // ['周一', '周二', '周三', '周四', '周五', '周六', '周日']
      name: targetDataName,
      nameLocation: 'center',
      nameGap: 26
    },
    yAxis: {
      type: 'value'
    },
    series: _seriesData
  };

  // 使用刚指定的配置项和数据显示图表。
  myChart.setOption(option);
}
